Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(238)

Unified Diff: pkg/barback/test/utils.dart

Issue 25376003: Add support for transformer clusters to barback. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Expose the Operator class. Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/barback/test/utils.dart
diff --git a/pkg/barback/test/utils.dart b/pkg/barback/test/utils.dart
index 7fb1a23b0ee4da94378de14c4d6ff163bf4135f7..85a9c6179942238b1288ed9aee4c407bec67d49e 100644
--- a/pkg/barback/test/utils.dart
+++ b/pkg/barback/test/utils.dart
@@ -88,7 +88,7 @@ void initGraph([assets,
_barback = new Barback(_provider);
_nextBuildResult = 0;
- transformers.forEach(_barback.updateTransformers);
+ transformers.forEach(_barback.updateOperators);
// There should be one successful build after adding all the transformers but
// before adding any sources.
@@ -131,11 +131,11 @@ void removeSources(Iterable assets) {
void removeSourcesSync(Iterable assets) =>
_barback.removeSources(_parseAssets(assets));
-/// Sets the transformers for [package] to [transformers].
-void updateTransformers(String package,
- Iterable<Iterable<Transformer>> transformers) {
- schedule(() => _barback.updateTransformers(package, transformers),
- "updating transformers for $package");
+/// Sets the operators for [package] to [operators].
+void updateOperators(String package,
+ Iterable<Iterable<Operator>> operators) {
+ schedule(() => _barback.updateOperators(package, operators),
+ "updating operators for $package");
}
/// Parse a list of strings or [AssetId]s into a list of [AssetId]s.

Powered by Google App Engine
This is Rietveld 408576698